@@ -22,6 +22,7 @@ class ConnectionStateResponse(KNXIPBodyResponse):
     """Representation of a KNX Connection State Response."""
 
     SERVICE_TYPE = KNXIPServiceType.CONNECTIONSTATE_RESPONSE
+    LENGTH = 2
 
     def __init__(
         self,
@@ -36,35 +37,19 @@ class ConnectionStateResponse(KNXIPBodyResponse):
 
     def calculated_length(self) -> int:
         """Get length of KNX/IP body."""
-        return 2
+        return ConnectionStateResponse.LENGTH
 
     def from_knx(self, raw: bytes) -> int:
         """Parse/deserialize from KNX/IP raw data."""
-
-        def info_from_knx(info: bytes) -> int:
-            """Parse info bytes."""
-            if len(info) < 2:
-                raise CouldNotParseKNXIP("info has wrong length")
-            self.communication_channel_id = info[0]
-            self.status_code = ErrorCode(info[1])
-            return 2
-
-        pos = info_from_knx(raw)
-        return pos
+        if len(raw) < ConnectionStateResponse.LENGTH:
+            raise CouldNotParseKNXIP("ConnectionStateResponse info has wrong length")
+        self.communication_channel_id = raw[0]
+        self.status_code = ErrorCode(raw[1])
+        return ConnectionStateResponse.LENGTH
 
     def to_knx(self) -> list[int]:
         """Serialize to KNX/IP raw data."""
-
-        def info_to_knx() -> list[int]:
-            """Serialize information bytes."""
-            info = []
-            info.append(self.communication_channel_id)
-            info.append(self.status_code.value)
-            return info
-
-        data = []
-        data.extend(info_to_knx())
-        return data
+        return [self.communication_channel_id, self.status_code.value]
 
     def __str__(self) -> str:
         """Return object as readable string."""
