@@ -28,6 +28,11 @@ class HPAI:
         self.port = port
         self.protocol = protocol
 
+    @property
+    def route_back(self) -> bool:
+        """Return True if HPAI is a route back address information."""
+        return self.ip_addr == "0.0.0.0"
+
     def from_knx(self, raw: bytes) -> int:
         """Parse/deserialize from KNX/IP raw data."""
         if len(raw) < HPAI.LENGTH:
